import * as React from 'react';
import { fireEvent, render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlAccordion from './Accordion';

// Preparing component for rendering

const props = {
  children: 'Accordion content',
  header: 'Accordion title',
};

const selectors = {
  root: '.bl-accordion',
  clickable: '.bl-accordion__header',
};

const modifierClasses = {
  isOpen: 'bl-accordion--is-open',
};

const Accordion = <BlAccordion {...props} />;

// Tests

test('Accordion gets rendered as expected and has header and body text', async () => {
  render(Accordion);

  expect(screen.getByText(props.header)).toBeInTheDocument();
  expect(screen.getByText(props.children)).toBeInTheDocument();
});

test('Accordion gets correct class when clicked', async () => {
  const { container } = render(Accordion);

  const accordionHeader = container.querySelector(selectors.clickable);
  fireEvent.click(accordionHeader);

  const rootElement: HTMLElement = container.querySelector(selectors.root);
  expect(rootElement.classList.contains(modifierClasses.isOpen)).toBe(true);
});
