import * as React from 'react';
import { fireEvent, render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlAccordion from '../accordion/Accordion';
import BlAccordionList from './AccordionList';

// Preparing component for rendering

const accordionProps = {
  children: 'Accordion content',
  header: 'Accordion title',
};

const props = {
  hasToggleAll: true,
  langToggleOpen: 'Åpne alle',
  langToggleClose: 'Lukk alle',
};

const AccordionList = (
  <BlAccordionList {...props}>
    <BlAccordion {...accordionProps} />
    <BlAccordion {...accordionProps} />
    <BlAccordion {...accordionProps} />
  </BlAccordionList>
);

// Tests

test('AccordionList gets rendered as expected', async () => {
  render(AccordionList);

  expect(screen.getAllByText(accordionProps.header)[0]).toBeInTheDocument();
  expect(screen.getAllByText(accordionProps.children)[0]).toBeInTheDocument();
  expect(screen.getByText(props.langToggleOpen)).toBeInTheDocument();
});

test('Clicking toggle all changes the text of the toggle button', async () => {
  render(AccordionList);

  const btnToggleAll = screen.getByText(props.langToggleOpen);
  fireEvent.click(btnToggleAll);

  expect(screen.getByText(props.langToggleClose)).toBeInTheDocument();
});
