'use client';
/* eslint-disable jsx-a11y/interactive-supports-focus */
/* eslint-disable jsx-a11y/no-noninteractive-tabindex */
import React, { useEffect, useState, FC, useRef } from 'react';
import './CarouselModal.scss';

type ModalProps = {
  /**
   *  Rendered between title and button
   * */
  children: React.ReactNode;
  /**
   *  is open is handling modal to open/close based on true/false.
   * */
  isOpen: boolean;
  /**
   *  Callback to fire when the backdrop is clicked. Typically used to close the modal.
   * */
  onBackdropClick?: () => void;
  /**
   *  Language for aria-label on backdrop
   * */
  langAriaModalClose?: string;
  /**
   * Id for content to be used for setting focus after last element is tabbed away from.
   * I.e `document.getElementById('bl-carousel-modal-content')?.focus();`
   * */
  contentId?: string;
};

/**
 * Very simple modal that adds a backdrop behind the children passed in.
 * */
const Modal: FC<ModalProps> = ({
  children,
  isOpen,
  onBackdropClick,
  langAriaModalClose = 'Lukk Modal',
  contentId = 'bl-carousel-modal-content',
}) => {
  const [isModalOpen, setIsModalOpen] = useState(false);
  const modalBodyRef = useRef<HTMLDivElement>(null);

  useEffect(() => {
    setIsModalOpen(isOpen);
  }, [isOpen]);

  useEffect(() => {
    document.body.style.overflow = isModalOpen ? 'hidden' : 'unset';
    if (isModalOpen) {
      modalBodyRef.current?.focus();
    }
  }, [isModalOpen]);

  return (
    <div
      className={`bl-carousel-modal ${
        isModalOpen ? 'bl-carousel-modal--is-open' : ''
      }`}
    >
      <div className="bl-carousel-modal__content">
        {isModalOpen && (
          <>
            <div
              id={contentId}
              role="dialog"
              ref={modalBodyRef}
              className="bl-carousel-modal__children"
              tabIndex={0}
            >
              {children}
            </div>
            <div
              role="button"
              aria-label={langAriaModalClose}
              className="bl-carousel-modal__backdrop"
              onClick={() => onBackdropClick && onBackdropClick()}
              onKeyDown={(e) =>
                e.key === 'Enter' ? onBackdropClick && onBackdropClick() : null
              }
            />
          </>
        )}
      </div>
    </div>
  );
};
export default Modal;
