import * as React from 'react';
import { vi } from 'vitest';
import { render, screen, fireEvent } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlCheckbox from './Checkbox';

// Preparing component for rendering

const props = {
  label: 'Checkbox text',
  onChange: vi.fn(),
};

const Checkbox = <BlCheckbox {...props} />;

// Tests

test('Checkbox gets rendered as expected and has a label', async () => {
  render(Checkbox);

  expect(screen.getByText(props.label)).toBeInTheDocument();
});

test('Checkbox gets checked when clicked (uncontrolled input)', async () => {
  const { container } = render(<BlCheckbox {...props} />);

  const checkboxLabel = container.getElementsByTagName('label')[0];
  fireEvent.click(checkboxLabel);

  const input: HTMLInputElement = container.querySelector('input');
  expect(input.checked).toBe(true);
});

test('Checkbox gets checked when isChecked prop is true (controlled input)', async () => {
  const { container } = render(<BlCheckbox {...props} isChecked />);

  const input: HTMLInputElement = container.querySelector('input');
  expect(input.checked).toBe(true);
});
