import * as React from 'react';
import { render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlHero from './Hero';
import { BlResponsiveImage } from '../..';

// Preparing component for rendering

type Theme = 'primary' | 'secondary' | 'tertiary';

const theme: Theme = 'primary';

const props = {
  imageElement: (
    <BlResponsiveImage
      url="https://via.placeholder.com/560x380"
      mobileUrl="https://via.placeholder.com/360x280"
      ariaText="Hero Image"
      credit="Image Credit"
      caption="Image Caption"
    />
  ),
  theme,
  isCenterText: true,
};

const selectors = {
  root: '.bl-hero',
  tile: '.bl-tile',
};

const modifierClasses = {
  themePrimary: 'bl-tile--primary',
  isCenterText: 'bl-text-center',
};

const Hero = (
  <BlHero {...props}>
    <h1>Hero Title</h1>
    <p>Hero Content</p>
  </BlHero>
);

// Tests

test('Hero renders with image, centered text, and primary theme', () => {
  const { container } = render(Hero);

  const heroImage = screen.getByAltText('Hero Image');
  const imageCaption = screen.getByText('Image Caption');
  const imageCredit = screen.getByText('Image Credit');
  const heroTitle = screen.getByText('Hero Title');
  const heroContent = screen.getByText('Hero Content');
  expect(heroImage).toBeInTheDocument();
  expect(imageCaption).toBeInTheDocument();
  expect(imageCredit).toBeInTheDocument();
  expect(heroTitle).toBeInTheDocument();
  expect(heroContent).toBeInTheDocument();

  const tile: HTMLElement = container.querySelector(selectors.tile);
  expect(tile.classList.contains(modifierClasses.themePrimary)).toBe(true);
  expect(tile.classList.contains(modifierClasses.isCenterText)).toBe(true);
});
