import React from 'react';

import './Hero.scss';

type HeroProps = {
  /**
   * Image component that generates an `<img>` tag. For example BlResponsiveImage.
   */
  imageElement?: React.ReactNode;
  /**
   * Whether to have alternate colors/themes for tile.
   * */
  theme?: 'primary' | 'secondary' | 'tertiary';
  /**
   * Whether the content text is centered or not.
   * */
  isCenterText?: boolean;
  /**
   * Child elements i.e. Tile
   * */
  children?: React.ReactNode;
};

/**
 * Hero Component with big image with a tile containing text.
 * Can be used as only content in tile or only image.
 */
const Hero: React.FC<HeroProps> = ({
  children = null,
  theme = null,
  isCenterText = true,
  imageElement,
}) => (
  <div className={`bl-hero ${imageElement ? 'bl-hero--has-image' : ''}`}>
    {imageElement && <div className="bl-hero__image">{imageElement}</div>}
    {children && (
      <div className="bl-hero__content">
        <div
          className={`bl-tile bl-tile--${theme} ${
            isCenterText ? 'bl-text-center' : ''
          }`}
        >
          {children}
        </div>
      </div>
    )}
  </div>
);

export default Hero;
