import React from 'react';
import './InfoBox.scss';

type InfoBoxProps = {
  /**
   * Header string or element (ie. `{(<h3> My headline </h3>)}`)
   */
  header?: React.ReactNode;
  /**
   * Child elements or string
   */
  children?: React.ReactNode;
  /**
   *  Different variants declaring severity of information.
   * */
  state?: 'info' | 'success' | 'warning' | 'error';
  /**
   *  Remove icon from title
   * */
  hasNoIcon?: boolean;
  /**
   *  specify aria-live value for screen readers, default is null
   *  i.e. attribute is not rendered
   * */
  ariaLive?: 'polite' | 'assertive' | 'off';
};

/**
 * InfoBox component that consists mainly of a header with medium sized information icon, text and source/link.
 */
const InfoBox: React.FC<InfoBoxProps> = ({
  children = null,
  header,
  state = 'info',
  hasNoIcon = false,
  ariaLive = null,
}) => (
  <div className={`bl-info-box bl-info-box--${state}`} aria-live={ariaLive}>
    <div className="bl-info-box__wrapper">
      {header && (
        <div className="bl-info-box__header">
          {!hasNoIcon && (
            <i
              className={`bl-info-box__icon bl-icon--${state} bl-icon--medium`}
            />
          )}
          <div className="bl-info-box__header-content">{header}</div>
        </div>
      )}
      {children && <div className="bl-info-box__content">{children}</div>}
    </div>
  </div>
);

export default InfoBox;
