import * as React from 'react';
import { vi } from 'vitest';
import { render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlInput from './Input';

// Preparing component for rendering

const props = {
  label: 'Input text',
  value: 'Input value',
  onChange: vi.fn(),
};

const validationMessage = 'Validation message';

const Input = <BlInput {...props} />;

// Tests

test('Input gets rendered as expected and has a label', async () => {
  render(Input);

  expect(screen.getByText(props.label)).toBeInTheDocument();
});

test('Input gets text (controlled input)', async () => {
  render(Input);

  expect(screen.getByLabelText(props.label)).toHaveValue(props.value);
});

test('Input gets validation', async () => {
  render(<BlInput {...props} state="error" message={validationMessage} />);

  expect(screen.getByText(validationMessage)).toBeInTheDocument();
});
