'use client';
import React, { forwardRef } from 'react';
import Validation from '../validation/Validation';

type InputProps = {
  /**
   * Label for the input.
   * */
  label: string;
  /**
   * Type for the input.
   * */
  type?: string;
  /**
   * Value for the input.
   * */
  value?: string;
  /**
   * Placeholder for the input.
   * */
  placeholder?: string;
  /**
   * select elements onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
   * */
  onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void;
  /**
   * State of the input.
   * */
  state?: 'success' | 'warning' | 'error';
  /**
   * Validation message.
   * */
  message?: string;
  /**
   * Whether or not the input field is disabled.
   * */
  isDisabled?: boolean;
  /**
   * All extra props is passed to the input element.
   * */
  [x: string]: any;
};

/**
 * A wrapper around the input type input element. All extra props is passed to the input element.
 */
const Input: React.FC<InputProps> = forwardRef<HTMLInputElement, InputProps>(
  (
    {
      label,
      type = 'text',
      value,
      placeholder,
      onChange,
      state,
      message,
      isDisabled,
      ...rest
    },
    ref,
  ) => {
    return (
      <div>
        <label className="bl-size-6 bl-display-block">
          {label}
          <input
            {...rest}
            ref={ref}
            className={`bl-input${state ? ` bl-input--${state}` : ''} bl-m-t-1`}
            onChange={onChange}
            type={type}
            value={value}
            disabled={isDisabled}
            placeholder={placeholder}
          />
          {message && (
            <div className="bl-p-t-1">
              <Validation state={state}>{message}</Validation>
            </div>
          )}
        </label>
      </div>
    );
  },
);

export default Input;
