'use client';
import React from 'react';

import './MenuButton.scss';

type MenuButtonProps = {
  /**
   * Whether or not the button is active
   * */
  isActive?: boolean;
  /**
   * Button text when inactive
   * */
  langInactive?: string;
  /**
   * Button title when inactive
   * */
  langInactiveHint?: string;
  /**
   * Button text when active
   * */
  langActive?: string;
  /**
   * Button title when active
   * */
  langActiveHint?: string;
  /**
   * function to fire on click
   * */
  onClick: () => void;
  /**
   * All extra props is passed to the button element.
   * */
  [x: string]: any;
};

const MenuButton: React.FC<MenuButtonProps> = ({
  onClick,
  isActive = false,
  langInactive = 'Meny',
  langInactiveHint = 'Åpne meny',
  langActive = 'Lukk',
  langActiveHint = 'Lukk meny',
  ...rest
}) => {
  return (
    <button
      {...rest}
      aria-expanded={isActive}
      className={`bl-menu-button bl-size-3
        ${isActive ? ' bl-menu-button--active' : ' bl-menu-button--inactive'}
        `}
      onClick={onClick}
      type="button"
      title={isActive ? langActiveHint : langInactiveHint}
    >
      <span className="bl-menu-button__text bl-text-neutral-1">
        {isActive ? langActive : langInactive}
      </span>
      <div className="bl-menu-button__icon bl-m-l-3" />
    </button>
  );
};

export default MenuButton;
