import * as React from 'react';
import { fireEvent, render, screen } from '@testing-library/react';
import { vi } from 'vitest';
import '@testing-library/jest-dom';
import BlModal from './Modal';

// Mocking missing dialog methods

HTMLDialogElement.prototype.show = vi.fn(function mock(
  this: HTMLDialogElement,
) {
  this.open = true;
});

HTMLDialogElement.prototype.showModal = vi.fn(function mock(
  this: HTMLDialogElement,
) {
  this.open = true;
});

HTMLDialogElement.prototype.close = vi.fn(function mock(
  this: HTMLDialogElement,
) {
  this.open = false;
});

// Preparing component for rendering

const props = {
  children: 'Modal content',
  title: 'Modal title',
};

const Modal = <BlModal {...props} />;

// Tests

test('Modal gets rendered as expected', async () => {
  render(Modal);

  expect(screen.getByText(props.title)).toBeInTheDocument();
  expect(screen.getByText(props.children)).toBeInTheDocument();
});

test('Modal is closed by default', async () => {
  const { container } = render(Modal);

  const dialog: HTMLDialogElement = container.querySelector('dialog');
  expect(dialog.open).toBe(false);
});

test('Modal is open when prop isOpen is true', async () => {
  const { container } = render(<BlModal {...props} isOpen />);

  const dialog: HTMLDialogElement = container.querySelector('dialog');
  expect(dialog.open).toBe(true);
});

test('Modal closes when clicking outside', async () => {
  const { container } = render(<BlModal {...props} isOpen />);

  const dialog: HTMLDialogElement = container.querySelector('dialog');

  expect(dialog.open).toBe(true);

  fireEvent.click(document.body);

  // wait for async useEffect to finish
  setTimeout(() => {
    expect(dialog.open).toBe(false);
  }, 100);
});
