import * as React from 'react';
import { vi } from 'vitest';
import { fireEvent, render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlMultiselect from './Multiselect';
import BlCheckbox from '../checkbox/Checkbox';

// Preparing component for rendering

const props = {
  label: 'Multiselect label',
  buttonText: 'Multiselect button text',
  onChange: vi.fn(),
};

const selectors = {
  root: '.bl-multiselect',
  clickable: '.bl-multiselect__button',
};

const modifierClasses = {
  isOpen: 'bl-multiselect--is-open',
};

const Multiselect = (
  <BlMultiselect {...props}>
    <BlCheckbox onChange={vi.fn()} label="Checkbox 1" />
    <BlCheckbox onChange={vi.fn()} label="Checkbox 2" />
    <BlCheckbox onChange={vi.fn()} label="Checkbox 3" />
  </BlMultiselect>
);

// Tests

test('Multiselect gets rendered as expected and has a label', async () => {
  render(Multiselect);

  expect(screen.getByText(props.buttonText)).toBeInTheDocument();
});

test('Multiselect gets correct class when clicked', async () => {
  const { container } = render(Multiselect);

  const btnLabel = container.querySelector(selectors.clickable);
  fireEvent.click(btnLabel);

  const rootElement: HTMLElement = container.querySelector(selectors.root);
  expect(rootElement.classList.contains(modifierClasses.isOpen)).toBe(true);
});
