import * as React from 'react';
import { vi } from 'vitest';
import { render, screen, fireEvent } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlRadioButton from './RadioButton';

// Preparing component for rendering

const props = {
  label: 'RadioButton text',
  onChange: vi.fn(),
};

const RadioButton = <BlRadioButton {...props} />;

// Tests

test('RadioButton gets rendered as expected and has a label', async () => {
  render(RadioButton);

  expect(screen.getByText(props.label)).toBeInTheDocument();
});

test('RadioButton gets checked when clicked (uncontrolled input)', async () => {
  const { container } = render(<BlRadioButton {...props} />);

  const checkboxLabel = container.getElementsByTagName('label')[0];
  fireEvent.click(checkboxLabel);

  const input: HTMLInputElement = container.querySelector('input');
  expect(input.checked).toBe(true);
});

test('RadioButton gets checked when isChecked prop is true (controlled input)', async () => {
  const { container } = render(<BlRadioButton {...props} isChecked />);

  const input: HTMLInputElement = container.querySelector('input');
  expect(input.checked).toBe(true);
});
