import React from 'react';
import { render, screen } from '@testing-library/react';
import BlResponsiveImage from './ResponsiveImage';

const props = {
  url: 'default.jpg',
  ariaText: 'Image alt text',
  caption: 'This is the caption.',
};

const selectors = {
  sourceElement: 'source',
};

const imagePaths = {
  default: 'default.jpg',
  mobile: 'mobile.jpg',
  tablet: 'tablet.jpg',
  desktop: 'desktop.jpg',
  widescreen: 'widescreen.jpg',
};

const ResponsiveImage = <BlResponsiveImage {...props} />;

test('ResponsiveImage renders with url and caption', () => {
  render(ResponsiveImage);

  const imageElement: HTMLImageElement = screen.getByAltText(props.ariaText);
  const captionElement = screen.getByText(props.caption);
  expect(imageElement).toBeInTheDocument();
  expect(captionElement).toBeInTheDocument();
  expect(imageElement.src).toContain(imagePaths.default);
});

test('ResponsiveImage renders different image URLs for specific screen sizes', () => {
  const { container } = render(
    <BlResponsiveImage
      {...props}
      mobileUrl="mobile.jpg"
      tabletUrl="tablet.jpg"
      desktopUrl="desktop.jpg"
      widescreenUrl="widescreen.jpg"
    />,
  );

  const sourceElements: NodeListOf<HTMLSourceElement> =
    container.querySelectorAll(selectors.sourceElement);
  expect(sourceElements[0].srcset).toContain(imagePaths.mobile);
  expect(sourceElements[1].srcset).toContain(imagePaths.tablet);
  expect(sourceElements[2].srcset).toContain(imagePaths.desktop);
  expect(sourceElements[3].srcset).toContain(imagePaths.widescreen);
});
