import * as React from 'react';
import { vi } from 'vitest';
import { fireEvent, render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlSearch from './Search';

// Preparing component for rendering

const props = {
  buttonText: 'Search text',
  placeholder: 'Search placeholder',
  onClickSearch: vi.fn(),
  onClickShow: vi.fn(),
};

const Search = <BlSearch {...props} />;

// Tests

test('Search gets rendered as expected and has button text', async () => {
  render(Search);

  expect(screen.getByText(props.buttonText)).toBeInTheDocument();
});

test('Search gets text (self controlled input)', async () => {
  render(Search);

  const inputText = 'I am writing this text to test the search input.';

  fireEvent.change(screen.getByPlaceholderText(props.placeholder), {
    target: {
      value: inputText,
    },
  });

  expect(screen.getByPlaceholderText(props.placeholder)).toHaveValue(inputText);
});
