import * as React from 'react';
import { fireEvent, render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlSelect from './Select';

// Preparing component for rendering

let currentOption = 'volvo';

const props = {
  label: 'Select text',
  value: 'volvo',
  onChange: (e) => {
    currentOption = e.target.value;
  },
};

const Select = (
  <BlSelect {...props}>
    <option value="volvo">Volvo</option>
    <option value="saab">Saab</option>
    <option value="mercedes">Mercedes</option>
    <option value="audi">Audi</option>
  </BlSelect>
);

// Tests

test('Select gets rendered as expected and has a label and the correct default value', async () => {
  render(Select);

  expect(screen.getByText(props.label)).toBeInTheDocument();
  expect(screen.getByLabelText(props.label)).toHaveValue(props.value);
});

test('Select changes value correctly (controlled input)', async () => {
  render(Select);

  expect(currentOption).toBe('volvo');

  fireEvent.change(screen.getByLabelText(props.label), {
    target: {
      value: 'audi',
    },
  });

  expect(currentOption).toBe('audi');
});
