import * as React from 'react';
import { vi } from 'vitest';
import { render, screen, fireEvent } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlTag from './Tag';

// Preparing component for rendering

const props = {
  ariaText: 'Tag aria text',
  children: 'Tag text',
  onClick: vi.fn(),
};

const Tag = <BlTag {...props} />;

// Tests

test('Tag gets rendered as expected and has a label', async () => {
  render(Tag);

  expect(screen.getByText(props.children)).toBeInTheDocument();
});

test('calls onClick callback when clicked', () => {
  const { getByText } = render(Tag);

  const tagElement = getByText(props.children);
  fireEvent.click(tagElement);
  expect(props.onClick).toHaveBeenCalledTimes(1);
});
