import * as React from 'react';
import { render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlTeaser from './Teaser';
import { BlResponsiveImage } from '../..';

// Preparing component for rendering

type ImagePosition = 'left' | 'right';

const imagePosition: ImagePosition = 'left';

const props = {
  children: 'Teaser content',
  header: 'Teaser header',
  imagePosition,
  imageElement: (
    <BlResponsiveImage
      url="https://via.placeholder.com/560x380"
      mobileUrl="https://via.placeholder.com/360x280"
      ariaText="Alternative image text"
    />
  ),
};

const modifierClasses = {
  imageLeft: '.bl-teaser--image-left',
};

const Teaser = <BlTeaser {...props} />;

// Tests

test('Teaser gets rendered as expected and has header and body text', async () => {
  render(Teaser);

  expect(screen.getByText(props.header)).toBeInTheDocument();
  expect(screen.getByText(props.children)).toBeInTheDocument();
});

test('Teaser gets image', async () => {
  render(Teaser);

  const image = screen.getByRole('img');
  expect(image).toBeInTheDocument();
});

test('Teaser gets correct modifier class for image', async () => {
  const { container } = render(Teaser);

  expect(
    container.querySelector(modifierClasses.imageLeft),
  ).toBeInTheDocument();
});
