import React from 'react';

import './Teaser.scss';

type TeaserProps = {
  /**
   * Image component that generates an `<img>` tag. For example BlResponsiveImage.
   */
  imageElement?: React.ReactNode;
  /**
   *  Image position can be left or right on desktop
   * */
  imagePosition?: undefined | 'left' | 'right';
  /**
   * Headline text/title.
   */
  header?: React.ReactNode;
  /**
   * Children
   */
  children?: React.ReactNode;
};

/**
 * This is a Teaser component that might have an image, some content and links.
 * Typically used to display part of the content found on a linked page.
 */
const Teaser: React.FC<TeaserProps> = ({
  children = null,
  header = null,
  imageElement,
  imagePosition,
}) => (
  <div
    className={`bl-teaser${
      imagePosition === 'left' ? ' bl-teaser--image-left' : ''
    }${imagePosition === 'right' ? ' bl-teaser--image-right' : ''}`}
  >
    {imageElement && <div className="bl-teaser__image">{imageElement}</div>}
    <div className="bl-teaser__content">
      {header && <div className="bl-teaser__title bl-size-2">{header}</div>}

      {children && (
        <div className="bl-teaser__consumer-content">{children}</div>
      )}
    </div>
  </div>
);

export default Teaser;
