import * as React from 'react';
import { vi } from 'vitest';
import { render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import BlTextArea from './TextArea';

// Preparing component for rendering

const props = {
  label: 'TextArea text',
  value: 'TextArea value',
  onChange: vi.fn(),
};

const validationMessage = 'Validation message';

const TextArea = <BlTextArea {...props} />;

// Tests

test('TextArea gets rendered as expected and has a label', async () => {
  render(TextArea);

  expect(screen.getByText(props.label)).toBeInTheDocument();
});

test('TextArea gets text (controlled input)', async () => {
  render(TextArea);

  expect(screen.getByLabelText(props.label)).toHaveValue(props.value);
});

test('TextArea gets validation', async () => {
  render(<BlTextArea {...props} state="error" message={validationMessage} />);

  expect(screen.getByText(validationMessage)).toBeInTheDocument();
});
