'use client';
import React, { forwardRef } from 'react';
import Validation from '../validation/Validation';

type TextAreaProps = {
  /**
   * Label for the textarea.
   * */
  label: string;
  /**
   * Value for the textarea.
   * */
  value?: string;
  /**
   * Placeholder for the textarea.
   * */
  placeholder?: string;
  /**
   * select elements onChange event that returns the native onchange event. Log value example: onChange={(e) => {console.log(e.target.value)}}
   * */
  onChange?: (e: React.ChangeEvent<HTMLTextAreaElement>) => void;
  /**
   * State of the textarea.
   * */
  state?: 'success' | 'warning' | 'error';
  /**
   * Validation message.
   * */
  message?: string;
  /**
   * Whether or not the textarea is disabled.
   * */
  isDisabled?: boolean;
  /**
   * All extra props is passed to the textarea element.
   * */
  [x: string]: any;
};

/**
 * A wrapper around the textarea type textarea element. All extra props is passed to the textarea element.
 */
const TextArea: React.FC<TextAreaProps> = forwardRef<
  HTMLTextAreaElement,
  TextAreaProps
>(
  (
    {
      label,
      value,
      placeholder,
      onChange,
      state,
      message,
      isDisabled,
      ...rest
    },
    ref,
  ) => {
    return (
      <div>
        <label className="bl-size-6 bl-display-block">
          {label}
          <textarea
            {...rest}
            ref={ref}
            className={`bl-input${state ? ` bl-input--${state}` : ''} bl-m-t-1`}
            onChange={onChange}
            value={value}
            disabled={isDisabled}
            placeholder={placeholder}
          />
          {message && (
            <div className="bl-p-t-1">
              <Validation state={state}>{message}</Validation>
            </div>
          )}
        </label>
      </div>
    );
  },
);

export default TextArea;
