import React from 'react';

type ValidationProps = {
  /**
   * Child elements or string
   */
  children: React.ReactNode;
  /**
   *  Different variants declaring severity of information.
   * */
  state?: 'info' | 'success' | 'warning' | 'error';
  /**
   *  Remove icon from title
   * */
  hasNoIcon?: boolean;
  /**
   * All extra props is passed to the root element.
   * */
  [x: string]: any;
};

/**
 * Validation component with state options.
 *
 * Mainly to be used as form validation.
 */
const Validation: React.FC<ValidationProps> = ({
  children = null,
  state = 'info',
  hasNoIcon = false,
  ...rest
}) => (
  <div
    {...rest}
    className={`bl-validation bl-validation--${state}`}
    aria-live="polite"
  >
    {!hasNoIcon && <i className={`bl-icon--${state} bl-validation__icon`} />}
    {children}
  </div>
);

export default Validation;
