/* eslint-disable import/prefer-default-export */
import React, { useEffect } from 'react';

/**
 * Hook that runs a callback on clicks outside of the passed ref
 */
export const useOutsideRefClickCallback = (
  ref: React.MutableRefObject<HTMLDivElement>,
  callback: () => void,
) => {
  useEffect(() => {
    /**
     * Run callback if clicked on outside of element
     */
    const handleClickOutside = (event: MouseEvent) => {
      if (ref.current && !ref.current.contains(event.target as Node)) {
        callback();
      }
    };
    // Bind the event listener
    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      // Unbind the event listener on clean up
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [ref]);
};
